@@ -1,5 +1,5 @@
 package Form::Factory::Action::Meta::Class;
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 
 use Moose::Role;
@@ -10,12 +10,12 @@ Form::Factory::Action::Meta::Class - The meta-class for form actions
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
   package MyApp::Action::Foo;
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 
   use Form::Factory::Processor;
@@ -87,7 +87,11 @@ sub get_all_features {
         next unless $other_meta->meta->can('does_role');
         next unless $other_meta->meta->does_role('Form::Factory::Action::Meta::Class');
 
-        %all_features = (%{ $other_meta->features }, %all_features);
+        # Make sure inherited features don't clobber each other
+        while (my ($name, $feature_config) = each %{ $other_meta->features }) {
+            my $full_name = join('#', $name, $other_meta->name);
+            $all_features{$full_name} = $feature_config;
+        }
     }
 
     return \%all_features;
